Version 0.11.0 (Under development) — Version 0.11.0.dev0

# Version 0.11.0 (Under development)

## Changelog

### Bug fixes

- `SMOTENC` now handles mix types of data type such as `bool` and `pd.category` by delegating the conversion to scikit-learn encoder. #1002 by Guillaume Lemaitre.

- Handle sparse matrices in `SMOTEN` and raise a warning since it requires a conversion to dense matrices. #1003 by Guillaume Lemaitre.

### Compatibility

- Maintenance release for being compatible with scikit-learn >= 1.3.0. #999 by Guillaume Lemaitre.

### Deprecation

- The fitted attribute `ohe_` in `SMOTENC` is deprecated and will be removed in version 0.13. Use `categorical_encoder_` instead. #1000 by Guillaume Lemaitre.

### Enhancements

- `SMOTENC` now accepts a parameter `categorical_encoder` allowing to specify a `OneHotEncoder` with custom parameters. #1000 by Guillaume Lemaitre.

- `SMOTEN` now accepts a parameter `categorical_encoder` allowing to specify a `OrdinalEncoder` with custom parameters. A new fitted parameter `categorical_encoder_` is exposed to access the fitted encoder. #1001 by Guillaume Lemaitre.